public class IRBytecodeAdapter7 extends IRBytecodeAdapter6
IRBytecodeAdapter.BlockPassTypeSUPER_NOSPLAT_RESOLVED, SUPER_NOSPLAT_UNRESOLVED, SUPER_SPLAT_RESOLVED, SUPER_SPLAT_UNRESOLVEDadapter, ipc, MAX_ARGUMENTS, signature| Constructor and Description |
|---|
IRBytecodeAdapter7(SkinnyMethodAdapter adapter,
com.headius.invokebinder.Signature signature,
org.jruby.ir.targets.ClassData classData) |
| Modifier and Type | Method and Description |
|---|---|
void |
array(int length)
Construct an Array from elements on stack.
|
void |
checkpoint()
Perform a thread event checkpoint.
|
void |
getField(java.lang.String name)
Load instance variable from self.
|
void |
hash(int length)
Construct a Hash from elements on stack.
|
void |
invokeArrayDeref(java.lang.String file,
int line)
Invoke the array dereferencing method ([]) on an object other than self.
|
void |
invokeClassSuper(java.lang.String file,
int line,
java.lang.String name,
int arity,
boolean hasClosure,
boolean[] splatmap)
Invoke a superclass method from a class context.
|
void |
invokeInstanceSuper(java.lang.String file,
int line,
java.lang.String name,
int arity,
boolean hasClosure,
boolean[] splatmap)
Invoke a superclass method from an instance context.
|
void |
invokeOther(java.lang.String file,
int line,
java.lang.String name,
int arity,
IRBytecodeAdapter.BlockPassType blockPassType,
boolean isPotentiallyRefined)
Invoke a method on an object other than self.
|
void |
invokeOtherOneFixnum(java.lang.String file,
int line,
java.lang.String name,
long fixnum,
CallType callType)
Invoke a fixnum-receiving method on an object other than self.
|
void |
invokeOtherOneFloat(java.lang.String file,
int line,
java.lang.String name,
double flote,
CallType callType)
Invoke a float-receiving method on an object other than self.
|
void |
invokeSelf(java.lang.String file,
int line,
java.lang.String name,
int arity,
IRBytecodeAdapter.BlockPassType blockPassType,
CallType callType,
boolean isPotentiallyRefined)
Invoke a method on self.
|
void |
invokeUnresolvedSuper(java.lang.String file,
int line,
java.lang.String name,
int arity,
boolean hasClosure,
boolean[] splatmap)
Invoke a superclass method from an unresolved context.
|
void |
invokeZSuper(java.lang.String file,
int line,
java.lang.String name,
int arity,
boolean hasClosure,
boolean[] splatmap)
Invoke a superclass method from a zsuper in a block.
|
void |
kwargsHash(int length)
Construct a Hash based on keyword arguments pasesd to this method, for use in zsuper
Stack required: context, kwargs hash to dup, remaining elements of hash
|
void |
loadRuntime()
Push the JRuby runtime on the stack.
|
void |
prepareBlock(org.objectweb.asm.Handle handle,
Signature signature,
java.lang.String className)
Prepare a block for a subsequent call.
|
void |
pushBignum(java.math.BigInteger bigint)
Load a Bignum onto the stack.
|
void |
pushBoolean(boolean b)
Load a boolean onto the stack.
|
void |
pushByteList(org.jruby.util.ByteList bl)
Stack required: none
|
void |
pushDRegexp(java.lang.Runnable callback,
RegexpOptions options,
int arity)
Build a dynamic regexp.
|
void |
pushEncoding(org.jcodings.Encoding encoding)
Push an encoding on the stack.
|
void |
pushFixnum(long l)
Stack required: none
|
void |
pushFloat(double d)
Stack required: none
|
void |
pushFrozenString(org.jruby.util.ByteList bl,
int cr,
java.lang.String file,
int line)
Stack required: none
|
void |
pushNil()
Load nil onto the stack.
|
void |
pushRegexp(org.jruby.util.ByteList source,
int options)
Build and save a literal regular expression.
|
void |
pushString(org.jruby.util.ByteList bl,
int cr)
Stack required: none
|
void |
pushSymbol(java.lang.String sym,
org.jcodings.Encoding encoding)
Push a symbol on the stack
|
void |
putField(java.lang.String name)
Store instance variable into self.
|
buildArrayFromLocals, cacheValuePermanently, cacheValuePermanently, cacheValuePermanentlyLoadContext, callEqq, getGlobalVariable, inheritanceSearchConst, invoke, lexicalSearchConst, pushSymbol, pushSymbolProc, searchConst, searchModuleForConst, setGlobalVariable, yield, yieldSpecific, yieldValuesbfalse, btrue, cacheCallSite, endMethod, getClassData, getUniqueSiteName, goTo, invokeHelper, invokeHelper, invokeIRHelper, invokeStatic, invokeVirtual, isNil, isTrue, loadArgs, loadBlock, loadBlockType, loadContext, loadFrameClass, loadFrameName, loadLocal, loadSelf, loadSelfBlock, loadStaticScope, loadSuperName, mark, newLabel, newLocal, poll, pushHandle, pushObjectClass, pushUndefined, returnValue, startMethod, storeArgs, storeLocal, storeSelfpublic IRBytecodeAdapter7(SkinnyMethodAdapter adapter, com.headius.invokebinder.Signature signature, org.jruby.ir.targets.ClassData classData)
public void pushFixnum(long l)
IRBytecodeAdapterpushFixnum in class IRBytecodeAdapter6l - long value to push as a Fixnumpublic void pushFloat(double d)
IRBytecodeAdapterpushFloat in class IRBytecodeAdapter6d - double value to push as a Floatpublic void pushString(org.jruby.util.ByteList bl,
int cr)
IRBytecodeAdapterpushString in class IRBytecodeAdapter6bl - ByteList for the String to pushpublic void pushFrozenString(org.jruby.util.ByteList bl,
int cr,
java.lang.String file,
int line)
IRBytecodeAdapter6pushFrozenString in class IRBytecodeAdapter6bl - ByteList for the String to pushpublic void pushByteList(org.jruby.util.ByteList bl)
IRBytecodeAdapterpushByteList in class IRBytecodeAdapter6bl - ByteList to pushpublic void pushRegexp(org.jruby.util.ByteList source,
int options)
IRBytecodeAdapterpushRegexp in class IRBytecodeAdapter6options - options for the regexppublic void pushDRegexp(java.lang.Runnable callback,
RegexpOptions options,
int arity)
IRBytecodeAdapterpushDRegexp in class IRBytecodeAdapter6options - options for the regexparity - number of Strings passed inpublic void pushSymbol(java.lang.String sym,
org.jcodings.Encoding encoding)
sym - the symbol's string identifierpublic void loadRuntime()
IRBytecodeAdapterloadRuntime in class IRBytecodeAdapter6public void pushEncoding(org.jcodings.Encoding encoding)
IRBytecodeAdapterpushEncoding in class IRBytecodeAdapter6encoding - the encoding to pushpublic void invokeOther(java.lang.String file,
int line,
java.lang.String name,
int arity,
IRBytecodeAdapter.BlockPassType blockPassType,
boolean isPotentiallyRefined)
IRBytecodeAdapterinvokeOther in class IRBytecodeAdapter6name - name of the method to invokearity - arity of the callblockPassType - what type of closure is passedpublic void invokeArrayDeref(java.lang.String file,
int line)
IRBytecodeAdapterinvokeArrayDeref in class IRBytecodeAdapter6public void invokeOtherOneFixnum(java.lang.String file,
int line,
java.lang.String name,
long fixnum,
CallType callType)
IRBytecodeAdapterinvokeOtherOneFixnum in class IRBytecodeAdapter6name - name of the method to invokepublic void invokeOtherOneFloat(java.lang.String file,
int line,
java.lang.String name,
double flote,
CallType callType)
IRBytecodeAdapterinvokeOtherOneFloat in class IRBytecodeAdapter6name - name of the method to invokepublic void invokeSelf(java.lang.String file,
int line,
java.lang.String name,
int arity,
IRBytecodeAdapter.BlockPassType blockPassType,
CallType callType,
boolean isPotentiallyRefined)
IRBytecodeAdapterinvokeSelf in class IRBytecodeAdapter6file - the filename of the script making this callline - the line number where this call appearsname - name of the method to invokearity - arity of the callblockPassType - what type of closure is passedpublic void invokeInstanceSuper(java.lang.String file,
int line,
java.lang.String name,
int arity,
boolean hasClosure,
boolean[] splatmap)
IRBytecodeAdapterinvokeInstanceSuper in class IRBytecodeAdapter6file - the filename of the script making this callline - the line number where this call appearsname - name of the method to invokearity - arity of the arguments on the stackhasClosure - whether a block is passedsplatmap - a map of arguments to be splatted back into arg listpublic void invokeClassSuper(java.lang.String file,
int line,
java.lang.String name,
int arity,
boolean hasClosure,
boolean[] splatmap)
IRBytecodeAdapterinvokeClassSuper in class IRBytecodeAdapter6file - the filename of the script making this callline - the line number where this call appearsname - name of the method to invokearity - arity of the arguments on the stackhasClosure - whether a block is passedsplatmap - a map of arguments to be splatted back into arg listpublic void invokeUnresolvedSuper(java.lang.String file,
int line,
java.lang.String name,
int arity,
boolean hasClosure,
boolean[] splatmap)
IRBytecodeAdapterinvokeUnresolvedSuper in class IRBytecodeAdapter6file - the filename of the script making this callline - the line number where this call appearsname - name of the method to invokearity - arity of the arguments on the stackhasClosure - whether a block is passedsplatmap - a map of arguments to be splatted back into arg listpublic void invokeZSuper(java.lang.String file,
int line,
java.lang.String name,
int arity,
boolean hasClosure,
boolean[] splatmap)
IRBytecodeAdapterinvokeZSuper in class IRBytecodeAdapter6file - the filename of the script making this callline - the line number where this call appearsname - name of the method to invokearity - arity of the arguments on the stackhasClosure - whether a block is passedsplatmap - a map of arguments to be splatted back into arg listpublic void pushNil()
IRBytecodeAdapterpushNil in class IRBytecodeAdapter6public void pushBoolean(boolean b)
IRBytecodeAdapterpushBoolean in class IRBytecodeAdapter6b - the boolean to pushpublic void pushBignum(java.math.BigInteger bigint)
IRBytecodeAdapterpushBignum in class IRBytecodeAdapter6bigint - the value of the Bignum to pushpublic void putField(java.lang.String name)
IRBytecodeAdapterputField in class IRBytecodeAdapter6name - name of variable to storepublic void getField(java.lang.String name)
IRBytecodeAdaptergetField in class IRBytecodeAdapter6name - name of variable to loadpublic void array(int length)
IRBytecodeAdapterarray in class IRBytecodeAdapter6length - number of elementspublic void hash(int length)
IRBytecodeAdapterhash in class IRBytecodeAdapter6length - number of element pairspublic void kwargsHash(int length)
IRBytecodeAdapterkwargsHash in class IRBytecodeAdapter6length - number of element pairspublic void checkpoint()
IRBytecodeAdaptercheckpoint in class IRBytecodeAdapter6public void prepareBlock(org.objectweb.asm.Handle handle,
Signature signature,
java.lang.String className)
IRBytecodeAdapterprepareBlock in class IRBytecodeAdapter6Copyright © 2001-2018 JRuby. All Rights Reserved.